@@ -1,4 +1,3 @@
-
 # For terminal commands
 DEFAULT_MODEL_SECTION = 'Model'
 DEFAULT_OAUTH2_SECTION = 'OAuth2'
@@ -8,8 +7,7 @@ DEFAULT_MODEL_TIMEOUT = None
 
 MODEL_CONTAINER_PREFIX = 'bge-model-'
 TEST_SERVER_PORT = 9999
-TEST_SERVER_ENDPOINT = 'http://0.0.0.0:{}'.format(TEST_SERVER_PORT)
-
+TEST_SERVER_ENDPOINT = 'http://0.0.0.0'
 
 CLIENT_CREDENTIALS_CONFIGS = [
     ('client_id', {
@@ -23,21 +21,24 @@ CLIENT_CREDENTIALS_CONFIGS = [
         'secure': True
     }),
     ('endpoint', {
-        # 'default': 'https://api.bge.genomics.cn',
-        'default': 'http://127.0.0.1:8080',
+        'default': 'https://api.bge.genomics.cn',
         'type': 'str',
         'description': '访问域名'
     })
 ]
 
 TAB_CHOICES = [
-        ('genetic_diseases', '遗传疾病'),
-        ('health_risks', '健康风险'),
-        ('physiological_index', '生理指标'),
-        ('comprehensive', '综合'),
-        ('tools', '工具')
-    ]
-LANGUAGE_CHOICES = [('zh', '中文版'), ('en', 'English')]
+    ('genetic_diseases', '遗传疾病'),
+    ('health_risks', '健康风险'),
+    ('physiological_index', '生理指标'),
+    ('comprehensive', '综合'),
+    ('tools', '工具')
+]
+
+LANGUAGE_CHOICES = [
+    ('zh', '中文版'),
+    ('en', 'English')
+]
 
 TITLE_NAME = {
     'brief_intro': '简介',
@@ -54,3 +55,12 @@ API_TABLE = {
     'Success': '返回参数',
     'State': '参数'
 }
+
+# 上传数据长度大于或等于该值时采用分片上传 100MB
+MULTIPART_THRESHOLD = 100 * 1024 * 1024
+
+# 单个分片大小 50MB
+PART_SIZE = 50 * 1024 * 1024
+
+# 分片上传缺省线程数
+MULTIPART_NUM_THREADS = 4
